[Pkg-owncloud-commits] [owncloud] 58/73: Use /dev/urandom instead of /dev/random
David Prévot
taffit at alioth.debian.org
Fri Nov 8 23:09:12 UTC 2013
This is an automated email from the git hooks/post-receive script.
taffit pushed a commit to annotated tag v4.0.10
in repository owncloud.
commit 3ca5c71a0bbc330241a9b031c607aa81042fffa5
Author: Lukas Reschke <lukas at statuscode.ch>
Date: Mon Oct 15 19:21:37 2012 +0200
Use /dev/urandom instead of /dev/random
The usage of /dev/urandom is enough secure
---
lib/util.php | 10 +++++-----
1 file changed, 5 insertions(+), 5 deletions(-)
diff --git a/lib/util.php b/lib/util.php
index 8db3c30..26e8579 100644
--- a/lib/util.php
+++ b/lib/util.php
@@ -475,8 +475,8 @@ class OC_Util {
}
}
- // Try to use /dev/random
- $fp = @file_get_contents('/dev/random', false, null, 0, $length);
+ // Try to use /dev/urandom
+ $fp = @file_get_contents('/dev/urandom', false, null, 0, $length);
if ($fp !== FALSE) {
$string = substr(bin2hex($fp), 0, $length);
return $string;
@@ -509,12 +509,12 @@ class OC_Util {
}
}
- // Check /dev/random
- $fp = @file_get_contents('/dev/random', false, null, 0, 1);
+ // Check /dev/urandom
+ $fp = @file_get_contents('/dev/urandom', false, null, 0, 1);
if ($fp !== FALSE) {
return true;
}
return false;
}
-}
\ No newline at end of file
+}
--
Alioth's /usr/local/bin/git-commit-notice on /srv/git.debian.org/git/pkg-owncloud/owncloud.git
More information about the Pkg-owncloud-commits
mailing list